Documentation
¶
Index ¶
- func Assert(t *testing.T, input any, assertions []Assertion)
- func AssertE(input any, assertions []Assertion) error
- func TerraformOutputJMES[T any](t *testing.T, terraformOptions *terraform.Options, query string) T
- func TerraformOutputJMESAny(t *testing.T, terraformOptions *terraform.Options, query string) interface{}
- func TerraformOutputJMESAnyE(t *testing.T, terraformOptions *terraform.Options, query string) (interface{}, error)
- type Assertion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Assert ¶
Assert asserts the given input against the provided assertions. Fails the test if any assertion fails.
func AssertE ¶
AssertE asserts the given input against the provided assertions and returns an error if any assertion fails.
func TerraformOutputJMES ¶
TerraformOutputJMES calls terraform output, searches values using JMESPath and converts to the desired type. This fails the test on any errors
Types ¶
Click to show internal directories.
Click to hide internal directories.